@@ -1,5 +1,5 @@
 package Telegram::Bot::Brain;
-$Telegram::Bot::Brain::VERSION = '0.004';
+$Telegram::Bot::Brain::VERSION = '0.005';
 # ABSTRACT: A base class to make your very own Telegram bot
 
 
@@ -29,15 +29,15 @@ sub add_repeating_task {
 
   my $repeater = sub {
 
-      # Perform operation every $seconds seconds
-      my $last_check = time();
-      Mojo::IOLoop->recurring(0.1 => sub {
-                                  my $loop = shift;
-                                  my $now  = time();
-                                  return unless ($now - $last_check) >= $seconds;
-                                  $last_check = $now;
-                                  $task->($self);
-                              });
+    # Perform operation every $seconds seconds
+    my $last_check = time();
+    Mojo::IOLoop->recurring(0.1 => sub {
+                              my $loop = shift;
+                              my $now  = time();
+                              return unless ($now - $last_check) >= $seconds;
+                              $last_check = $now;
+                              $task->($self);
+                            });
   };
 
   # keep a copy
@@ -57,6 +57,19 @@ sub add_listener {
 }
 
 
+sub send_to_chat_id {
+  my $self    = shift;
+  my $chat_id = shift;
+  my $message = shift;
+
+  my $token = $self->token;
+  my $method = $message->send_method;
+  my $msgURL = "https://api.telegram.org/bot${token}/send". $method;
+
+  $self->ua->post($msgURL, form => { chat_id => $chat_id, %{ $message->as_hashref } });
+}
+
+
 sub send_message_to_chat_id {
   my $self    = shift;
   my $chat_id = shift;
@@ -136,7 +149,7 @@ Telegram::Bot::Brain - A base class to make your very own Telegram bot
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -195,9 +208,13 @@ a CODEREF to be executed if the previous criteria was true
 Each CODEREF is passed two arguments, this C<Telegram::Bot::Brain> object, and 
 the C<Telegram::Bot::Message> object, the message that was sent to us.
 
+=head2 send_to_chat_id
+
+Send a pre-constructed message (some subclass of L<Telegram::Bot::Message>) to a chat id.
+
 =head2 send_message_to_chat_id
 
-Send a text message to a chat_id (group or individual).
+Send a plain text message to a chat_id (group or individual).
 
 =head1 SEE ALSO
 
