@@ -1,20 +1,20 @@
 package Telegram::Bot::Message;
-$Telegram::Bot::Message::VERSION = '0.004';
-# ABSTRACT: The base class for Telegram messages
+$Telegram::Bot::Message::VERSION = '0.005';
+# ABSTRACT: The base class for Telegram messages incoming to the bot
 
 use Mojo::Base -base;
 use Mojo::JSON qw/from_json/;
 
-use Telegram::Bot::Message::User;
-use Telegram::Bot::Message::UserOrGroup;
-use Telegram::Bot::Message::Audio;
-use Telegram::Bot::Message::Document;
-use Telegram::Bot::Message::Video;
-use Telegram::Bot::Message::Sticker;
-use Telegram::Bot::Message::PhotoSize;
-use Telegram::Bot::Message::Sticker;
-use Telegram::Bot::Message::Contact;
-use Telegram::Bot::Message::Location;
+use Telegram::Bot::Object::User;
+use Telegram::Bot::Object::UserOrGroup;
+use Telegram::Bot::Object::Audio;
+use Telegram::Bot::Object::Document;
+use Telegram::Bot::Object::Video;
+use Telegram::Bot::Object::Sticker;
+use Telegram::Bot::Object::PhotoSize;
+use Telegram::Bot::Object::Sticker;
+use Telegram::Bot::Object::Contact;
+use Telegram::Bot::Object::Location;
 
 use Data::Dumper;
 
@@ -27,6 +27,8 @@ has 'forward_from';
 has 'forward_date';
 has 'reply_to_message';
 
+
+# the message might have several other optional parts
 has 'text';
 has 'audio';
 has 'document';
@@ -39,28 +41,23 @@ has 'location';
 has 'new_chat_participant';
 has 'left_chat_participant';
 
-
 sub fields {
-  return { 
-    'scalar' 
-     => [qw/message_id date text forward_date/],
-   'Telegram::Bot::Message' 
-     => [qw/reply_to_message/],
-   'Telegram::Bot::Message::User' 
-     => [qw/from 
-            new_chat_participant left_chat_participant
-            forward_from/],
+  return {
+          'scalar'                       => [qw/message_id date text forward_date/],
+          'Telegram::Bot::Message'       => [qw/reply_to_message/],
+          'Telegram::Bot::Object::User'  => [qw/from
+                                                new_chat_participant left_chat_participant
+                                                forward_from/],
 
-   'Telegram::Bot::Message::UserOrGroup' 
-     => [qw/chat/],
+          'Telegram::Bot::Object::UserOrGroup' => [qw/chat/],
 
-   'Telegram::Bot::Message::Audio'      => [qw/audio/],
-   'Telegram::Bot::Message::Document'   => [qw/document/],
-   'Telegram::Bot::Message::PhotoSize'  => [qw/photo/],
-   'Telegram::Bot::Message::Video'      => [qw/video/],
-   'Telegram::Bot::Message::Sticker'    => [qw/sticker/],
-   'Telegram::Bot::Message::Contact'    => [qw/contact/],
-   'Telegram::Bot::Message::Location'   => [qw/location/],
+          'Telegram::Bot::Object::Audio'      => [qw/audio/],
+          'Telegram::Bot::Object::Document'   => [qw/document/],
+          'Telegram::Bot::Object::PhotoSize'  => [qw/photo/],
+          'Telegram::Bot::Object::Video'      => [qw/video/],
+          'Telegram::Bot::Object::Sticker'    => [qw/sticker/],
+          'Telegram::Bot::Object::Contact'    => [qw/contact/],
+          'Telegram::Bot::Object::Location'   => [qw/location/],
   };
 }
 
@@ -75,32 +72,28 @@ sub create_from_json {
 
 sub create_from_hash {
   my $class = shift;
-  my $hash = shift;
-  my $msg  = $class->new;
-  # warn "creating a $class from " . Dumper ($hash) . "\n";
+  my $hash  = shift;
+  my $msg   = $class->new;
 
   foreach my $k (keys %{ $class->fields }) {
-    # warn " working on fields of type '$k'\n";
     if ($k eq 'scalar') {
       foreach my $field (@{ $class->fields->{scalar} } ) {
-        # warn "  field: $field\n";
         $msg->$field($hash->{$field});
       }
     }
     else {
       foreach my $field (@{ $class->fields->{$k} } ) {
-        # warn "  field: $field (" . Dumper($hash->{$field}) . ")\n";
         if (is_array($field)) {
           my @items;
           foreach my $item (@{ $hash->{$field} || [] }) {
-            my $o = $k->create_from_hash($item) 
+            my $o = $k->create_from_hash($item)
               if defined $hash->{$field};
             push @items, $o;
           }
           $msg->$field(\@items);
         }
         else {
-          my $o = $k->create_from_hash($hash->{$field}) 
+          my $o = $k->create_from_hash($hash->{$field})
             if defined $hash->{$field};
           $msg->$field($o);
         }
@@ -121,11 +114,11 @@ __END__
 
 =head1 NAME
 
-Telegram::Bot::Message - The base class for Telegram messages
+Telegram::Bot::Message - The base class for Telegram messages incoming to the bot
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 AUTHOR
 
